def add_number(num1, num2):
    return (num1 + num2)

def subtract_number(num1, num2):
    return (num1 - num2)

def multi_number(num1, num2):
    return (num1 * num2)

def dev_number(num1, num2):
    return (num1 / num2)

